@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2017 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2024 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,16 +22,18 @@
 //
 ////////////////////////////////////////////////////////////
 
-#ifndef SFML_FTP_HPP
-#define SFML_FTP_HPP
+#pragma once
 
 ////////////////////////////////////////////////////////////
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Network/Export.hpp>
+
 #include <SFML/Network/TcpSocket.hpp>
-#include <SFML/System/NonCopyable.hpp>
+
 #include <SFML/System/Time.hpp>
+
+#include <filesystem>
 #include <string>
 #include <vector>
 
@@ -44,93 +46,91 @@ class IpAddress;
 /// \brief A FTP client
 ///
 ////////////////////////////////////////////////////////////
-class SFML_NETWORK_API Ftp : NonCopyable
+class SFML_NETWORK_API Ftp
 {
 public:
-
     ////////////////////////////////////////////////////////////
     /// \brief Enumeration of transfer modes
     ///
     ////////////////////////////////////////////////////////////
-    enum TransferMode
+    enum class TransferMode
     {
-        Binary, ///< Binary mode (file is transfered as a sequence of bytes)
-        Ascii,  ///< Text mode using ASCII encoding
-        Ebcdic  ///< Text mode using EBCDIC encoding
+        Binary, //!< Binary mode (file is transferred as a sequence of bytes)
+        Ascii,  //!< Text mode using ASCII encoding
+        Ebcdic  //!< Text mode using EBCDIC encoding
     };
 
     ////////////////////////////////////////////////////////////
-    /// \brief Define a FTP response
+    /// \brief FTP response
     ///
     ////////////////////////////////////////////////////////////
     class SFML_NETWORK_API Response
     {
     public:
-
         ////////////////////////////////////////////////////////////
         /// \brief Status codes possibly returned by a FTP response
         ///
         ////////////////////////////////////////////////////////////
-        enum Status
+        enum class Status
         {
             // 1xx: the requested action is being initiated,
             // expect another reply before proceeding with a new command
-            RestartMarkerReply          = 110, ///< Restart marker reply
-            ServiceReadySoon            = 120, ///< Service ready in N minutes
-            DataConnectionAlreadyOpened = 125, ///< Data connection already opened, transfer starting
-            OpeningDataConnection       = 150, ///< File status ok, about to open data connection
+            RestartMarkerReply          = 110, //!< Restart marker reply
+            ServiceReadySoon            = 120, //!< Service ready in N minutes
+            DataConnectionAlreadyOpened = 125, //!< Data connection already opened, transfer starting
+            OpeningDataConnection       = 150, //!< File status ok, about to open data connection
 
             // 2xx: the requested action has been successfully completed
-            Ok                    = 200, ///< Command ok
-            PointlessCommand      = 202, ///< Command not implemented
-            SystemStatus          = 211, ///< System status, or system help reply
-            DirectoryStatus       = 212, ///< Directory status
-            FileStatus            = 213, ///< File status
-            HelpMessage           = 214, ///< Help message
-            SystemType            = 215, ///< NAME system type, where NAME is an official system name from the list in the Assigned Numbers document
-            ServiceReady          = 220, ///< Service ready for new user
-            ClosingConnection     = 221, ///< Service closing control connection
-            DataConnectionOpened  = 225, ///< Data connection open, no transfer in progress
-            ClosingDataConnection = 226, ///< Closing data connection, requested file action successful
-            EnteringPassiveMode   = 227, ///< Entering passive mode
-            LoggedIn              = 230, ///< User logged in, proceed. Logged out if appropriate
-            FileActionOk          = 250, ///< Requested file action ok
-            DirectoryOk           = 257, ///< PATHNAME created
+            Ok               = 200, //!< Command ok
+            PointlessCommand = 202, //!< Command not implemented
+            SystemStatus     = 211, //!< System status, or system help reply
+            DirectoryStatus  = 212, //!< Directory status
+            FileStatus       = 213, //!< File status
+            HelpMessage      = 214, //!< Help message
+            SystemType = 215, //!< NAME system type, where NAME is an official system name from the list in the Assigned Numbers document
+            ServiceReady          = 220, //!< Service ready for new user
+            ClosingConnection     = 221, //!< Service closing control connection
+            DataConnectionOpened  = 225, //!< Data connection open, no transfer in progress
+            ClosingDataConnection = 226, //!< Closing data connection, requested file action successful
+            EnteringPassiveMode   = 227, //!< Entering passive mode
+            LoggedIn              = 230, //!< User logged in, proceed. Logged out if appropriate
+            FileActionOk          = 250, //!< Requested file action ok
+            DirectoryOk           = 257, //!< PATHNAME created
 
             // 3xx: the command has been accepted, but the requested action
             // is dormant, pending receipt of further information
-            NeedPassword       = 331, ///< User name ok, need password
-            NeedAccountToLogIn = 332, ///< Need account for login
-            NeedInformation    = 350, ///< Requested file action pending further information
+            NeedPassword       = 331, //!< User name ok, need password
+            NeedAccountToLogIn = 332, //!< Need account for login
+            NeedInformation    = 350, //!< Requested file action pending further information
 
             // 4xx: the command was not accepted and the requested action did not take place,
             // but the error condition is temporary and the action may be requested again
-            ServiceUnavailable        = 421, ///< Service not available, closing control connection
-            DataConnectionUnavailable = 425, ///< Can't open data connection
-            TransferAborted           = 426, ///< Connection closed, transfer aborted
-            FileActionAborted         = 450, ///< Requested file action not taken
-            LocalError                = 451, ///< Requested action aborted, local error in processing
-            InsufficientStorageSpace  = 452, ///< Requested action not taken; insufficient storage space in system, file unavailable
+            ServiceUnavailable        = 421, //!< Service not available, closing control connection
+            DataConnectionUnavailable = 425, //!< Can't open data connection
+            TransferAborted           = 426, //!< Connection closed, transfer aborted
+            FileActionAborted         = 450, //!< Requested file action not taken
+            LocalError                = 451, //!< Requested action aborted, local error in processing
+            InsufficientStorageSpace = 452, //!< Requested action not taken; insufficient storage space in system, file unavailable
 
             // 5xx: the command was not accepted and
             // the requested action did not take place
-            CommandUnknown          = 500, ///< Syntax error, command unrecognized
-            ParametersUnknown       = 501, ///< Syntax error in parameters or arguments
-            CommandNotImplemented   = 502, ///< Command not implemented
-            BadCommandSequence      = 503, ///< Bad sequence of commands
-            ParameterNotImplemented = 504, ///< Command not implemented for that parameter
-            NotLoggedIn             = 530, ///< Not logged in
-            NeedAccountToStore      = 532, ///< Need account for storing files
-            FileUnavailable         = 550, ///< Requested action not taken, file unavailable
-            PageTypeUnknown         = 551, ///< Requested action aborted, page type unknown
-            NotEnoughMemory         = 552, ///< Requested file action aborted, exceeded storage allocation
-            FilenameNotAllowed      = 553, ///< Requested action not taken, file name not allowed
+            CommandUnknown          = 500, //!< Syntax error, command unrecognized
+            ParametersUnknown       = 501, //!< Syntax error in parameters or arguments
+            CommandNotImplemented   = 502, //!< Command not implemented
+            BadCommandSequence      = 503, //!< Bad sequence of commands
+            ParameterNotImplemented = 504, //!< Command not implemented for that parameter
+            NotLoggedIn             = 530, //!< Not logged in
+            NeedAccountToStore      = 532, //!< Need account for storing files
+            FileUnavailable         = 550, //!< Requested action not taken, file unavailable
+            PageTypeUnknown         = 551, //!< Requested action aborted, page type unknown
+            NotEnoughMemory         = 552, //!< Requested file action aborted, exceeded storage allocation
+            FilenameNotAllowed      = 553, //!< Requested action not taken, file name not allowed
 
             // 10xx: SFML custom codes
-            InvalidResponse  = 1000, ///< Not part of the FTP standard, generated by SFML when a received response cannot be parsed
-            ConnectionFailed = 1001, ///< Not part of the FTP standard, generated by SFML when the low-level socket connection with the server fails
-            ConnectionClosed = 1002, ///< Not part of the FTP standard, generated by SFML when the low-level socket connection is unexpectedly closed
-            InvalidFile      = 1003  ///< Not part of the FTP standard, generated by SFML when a local file cannot be read or written
+            InvalidResponse = 1000, //!< Not part of the FTP standard, generated by SFML when a received response cannot be parsed
+            ConnectionFailed = 1001, //!< Not part of the FTP standard, generated by SFML when the low-level socket connection with the server fails
+            ConnectionClosed = 1002, //!< Not part of the FTP standard, generated by SFML when the low-level socket connection is unexpectedly closed
+            InvalidFile = 1003 //!< Not part of the FTP standard, generated by SFML when a local file cannot be read or written
         };
 
         ////////////////////////////////////////////////////////////
@@ -143,7 +143,7 @@ public:
         /// \param message Response message
         ///
         ////////////////////////////////////////////////////////////
-        explicit Response(Status code = InvalidResponse, const std::string& message = "");
+        explicit Response(Status code = Status::InvalidResponse, std::string message = "");
 
         ////////////////////////////////////////////////////////////
         /// \brief Check if the status code means a success
@@ -151,10 +151,10 @@ public:
         /// This function is defined for convenience, it is
         /// equivalent to testing if the status code is < 400.
         ///
-        /// \return True if the status is a success, false if it is a failure
+        /// \return `true` if the status is a success, `false` if it is a failure
         ///
         ////////////////////////////////////////////////////////////
-        bool isOk() const;
+        [[nodiscard]] bool isOk() const;
 
         ////////////////////////////////////////////////////////////
         /// \brief Get the status code of the response
@@ -162,7 +162,7 @@ public:
         /// \return Status code
         ///
         ////////////////////////////////////////////////////////////
-        Status getStatus() const;
+        [[nodiscard]] Status getStatus() const;
 
         ////////////////////////////////////////////////////////////
         /// \brief Get the full message contained in the response
@@ -170,15 +170,14 @@ public:
         /// \return The response message
         ///
         ////////////////////////////////////////////////////////////
-        const std::string& getMessage() const;
+        [[nodiscard]] const std::string& getMessage() const;
 
     private:
-
         ////////////////////////////////////////////////////////////
         // Member data
         ////////////////////////////////////////////////////////////
-        Status      m_status;  ///< Status code returned from the server
-        std::string m_message; ///< Last message received from the server
+        Status      m_status;  //!< Status code returned from the server
+        std::string m_message; //!< Last message received from the server
     };
 
     ////////////////////////////////////////////////////////////
@@ -188,7 +187,6 @@ public:
     class SFML_NETWORK_API DirectoryResponse : public Response
     {
     public:
-
         ////////////////////////////////////////////////////////////
         /// \brief Default constructor
         ///
@@ -203,25 +201,23 @@ public:
         /// \return Directory name
         ///
         ////////////////////////////////////////////////////////////
-        const std::string& getDirectory() const;
+        [[nodiscard]] const std::filesystem::path& getDirectory() const;
 
     private:
-
         ////////////////////////////////////////////////////////////
         // Member data
         ////////////////////////////////////////////////////////////
-        std::string m_directory; ///< Directory extracted from the response message
+        std::filesystem::path m_directory; //!< Directory extracted from the response message
     };
 
 
     ////////////////////////////////////////////////////////////
     /// \brief Specialization of FTP response returning a
-    ///        filename listing
+    ///        file name listing
     ////////////////////////////////////////////////////////////
     class SFML_NETWORK_API ListingResponse : public Response
     {
     public:
-
         ////////////////////////////////////////////////////////////
         /// \brief Default constructor
         ///
@@ -237,16 +233,20 @@ public:
         /// \return Array containing the requested listing
         ///
         ////////////////////////////////////////////////////////////
-        const std::vector<std::string>& getListing() const;
+        [[nodiscard]] const std::vector<std::string>& getListing() const;
 
     private:
-
         ////////////////////////////////////////////////////////////
         // Member data
         ////////////////////////////////////////////////////////////
-        std::vector<std::string> m_listing; ///< Directory/file names extracted from the data
+        std::vector<std::string> m_listing; //!< Directory/file names extracted from the data
     };
 
+    ////////////////////////////////////////////////////////////
+    /// \brief Default constructor
+    ///
+    ////////////////////////////////////////////////////////////
+    Ftp() = default;
 
     ////////////////////////////////////////////////////////////
     /// \brief Destructor
@@ -257,6 +257,18 @@ public:
     ////////////////////////////////////////////////////////////
     ~Ftp();
 
+    ////////////////////////////////////////////////////////////
+    /// \brief Deleted copy constructor
+    ///
+    ////////////////////////////////////////////////////////////
+    Ftp(const Ftp&) = delete;
+
+    ////////////////////////////////////////////////////////////
+    /// \brief Deleted copy assignment
+    ///
+    ////////////////////////////////////////////////////////////
+    Ftp& operator=(const Ftp&) = delete;
+
     ////////////////////////////////////////////////////////////
     /// \brief Connect to the specified FTP server
     ///
@@ -266,7 +278,7 @@ public:
     /// This function tries to connect to the server so it may take
     /// a while to complete, especially if the server is not
     /// reachable. To avoid blocking your application for too long,
-    /// you can use a timeout. The default value, Time::Zero, means that the
+    /// you can use a timeout. The default value, `Time::Zero`, means that the
     /// system timeout will be used (which is usually pretty long).
     ///
     /// \param server  Name or address of the FTP server to connect to
@@ -275,20 +287,20 @@ public:
     ///
     /// \return Server response to the request
     ///
-    /// \see disconnect
+    /// \see `disconnect`
     ///
     ////////////////////////////////////////////////////////////
-    Response connect(const IpAddress& server, unsigned short port = 21, Time timeout = Time::Zero);
+    [[nodiscard]] Response connect(IpAddress server, unsigned short port = 21, Time timeout = Time::Zero);
 
     ////////////////////////////////////////////////////////////
     /// \brief Close the connection with the server
     ///
     /// \return Server response to the request
     ///
-    /// \see connect
+    /// \see `connect`
     ///
     ////////////////////////////////////////////////////////////
-    Response disconnect();
+    [[nodiscard]] Response disconnect();
 
     ////////////////////////////////////////////////////////////
     /// \brief Log in using an anonymous account
@@ -299,7 +311,7 @@ public:
     /// \return Server response to the request
     ///
     ////////////////////////////////////////////////////////////
-    Response login();
+    [[nodiscard]] Response login();
 
     ////////////////////////////////////////////////////////////
     /// \brief Log in using a username and a password
@@ -313,7 +325,7 @@ public:
     /// \return Server response to the request
     ///
     ////////////////////////////////////////////////////////////
-    Response login(const std::string& name, const std::string& password);
+    [[nodiscard]] Response login(const std::string& name, const std::string& password);
 
     ////////////////////////////////////////////////////////////
     /// \brief Send a null command to keep the connection alive
@@ -324,7 +336,7 @@ public:
     /// \return Server response to the request
     ///
     ////////////////////////////////////////////////////////////
-    Response keepAlive();
+    [[nodiscard]] Response keepAlive();
 
     ////////////////////////////////////////////////////////////
     /// \brief Get the current working directory
@@ -334,27 +346,27 @@ public:
     ///
     /// \return Server response to the request
     ///
-    /// \see getDirectoryListing, changeDirectory, parentDirectory
+    /// \see `getDirectoryListing`, `changeDirectory`, `parentDirectory`
     ///
     ////////////////////////////////////////////////////////////
-    DirectoryResponse getWorkingDirectory();
+    [[nodiscard]] DirectoryResponse getWorkingDirectory();
 
     ////////////////////////////////////////////////////////////
     /// \brief Get the contents of the given directory
     ///
     /// This function retrieves the sub-directories and files
     /// contained in the given directory. It is not recursive.
-    /// The \a directory parameter is relative to the current
+    /// The `directory` parameter is relative to the current
     /// working directory.
     ///
     /// \param directory Directory to list
     ///
     /// \return Server response to the request
     ///
-    /// \see getWorkingDirectory, changeDirectory, parentDirectory
+    /// \see `getWorkingDirectory`, `changeDirectory`, `parentDirectory`
     ///
     ////////////////////////////////////////////////////////////
-    ListingResponse getDirectoryListing(const std::string& directory = "");
+    [[nodiscard]] ListingResponse getDirectoryListing(const std::string& directory = "");
 
     ////////////////////////////////////////////////////////////
     /// \brief Change the current working directory
@@ -365,20 +377,20 @@ public:
     ///
     /// \return Server response to the request
     ///
-    /// \see getWorkingDirectory, getDirectoryListing, parentDirectory
+    /// \see `getWorkingDirectory`, `getDirectoryListing`, `parentDirectory`
     ///
     ////////////////////////////////////////////////////////////
-    Response changeDirectory(const std::string& directory);
+    [[nodiscard]] Response changeDirectory(const std::string& directory);
 
     ////////////////////////////////////////////////////////////
     /// \brief Go to the parent directory of the current one
     ///
     /// \return Server response to the request
     ///
-    /// \see getWorkingDirectory, getDirectoryListing, changeDirectory
+    /// \see `getWorkingDirectory`, `getDirectoryListing`, `changeDirectory`
     ///
     ////////////////////////////////////////////////////////////
-    Response parentDirectory();
+    [[nodiscard]] Response parentDirectory();
 
     ////////////////////////////////////////////////////////////
     /// \brief Create a new directory
@@ -390,10 +402,10 @@ public:
     ///
     /// \return Server response to the request
     ///
-    /// \see deleteDirectory
+    /// \see `deleteDirectory`
     ///
     ////////////////////////////////////////////////////////////
-    Response createDirectory(const std::string& name);
+    [[nodiscard]] Response createDirectory(const std::string& name);
 
     ////////////////////////////////////////////////////////////
     /// \brief Remove an existing directory
@@ -407,15 +419,15 @@ public:
     ///
     /// \return Server response to the request
     ///
-    /// \see createDirectory
+    /// \see `createDirectory`
     ///
     ////////////////////////////////////////////////////////////
-    Response deleteDirectory(const std::string& name);
+    [[nodiscard]] Response deleteDirectory(const std::string& name);
 
     ////////////////////////////////////////////////////////////
     /// \brief Rename an existing file
     ///
-    /// The filenames must be relative to the current working
+    /// The file names must be relative to the current working
     /// directory.
     ///
     /// \param file    File to rename
@@ -423,10 +435,10 @@ public:
     ///
     /// \return Server response to the request
     ///
-    /// \see deleteFile
+    /// \see `deleteFile`
     ///
     ////////////////////////////////////////////////////////////
-    Response renameFile(const std::string& file, const std::string& newName);
+    [[nodiscard]] Response renameFile(const std::filesystem::path& file, const std::filesystem::path& newName);
 
     ////////////////////////////////////////////////////////////
     /// \brief Remove an existing file
@@ -440,32 +452,34 @@ public:
     ///
     /// \return Server response to the request
     ///
-    /// \see renameFile
+    /// \see `renameFile`
     ///
     ////////////////////////////////////////////////////////////
-    Response deleteFile(const std::string& name);
+    [[nodiscard]] Response deleteFile(const std::filesystem::path& name);
 
     ////////////////////////////////////////////////////////////
     /// \brief Download a file from the server
     ///
-    /// The filename of the distant file is relative to the
+    /// The file name of the distant file is relative to the
     /// current working directory of the server, and the local
     /// destination path is relative to the current directory
     /// of your application.
-    /// If a file with the same filename as the distant file
+    /// If a file with the same file name as the distant file
     /// already exists in the local destination path, it will
     /// be overwritten.
     ///
-    /// \param remoteFile Filename of the distant file to download
+    /// \param remoteFile File name of the distant file to download
     /// \param localPath  The directory in which to put the file on the local computer
     /// \param mode       Transfer mode
     ///
     /// \return Server response to the request
     ///
-    /// \see upload
+    /// \see `upload`
     ///
     ////////////////////////////////////////////////////////////
-    Response download(const std::string& remoteFile, const std::string& localPath, TransferMode mode = Binary);
+    [[nodiscard]] Response download(const std::filesystem::path& remoteFile,
+                                    const std::filesystem::path& localPath,
+                                    TransferMode                 mode = TransferMode::Binary);
 
     ////////////////////////////////////////////////////////////
     /// \brief Upload a file to the server
@@ -475,26 +489,33 @@ public:
     /// remote path is relative to the current directory of the
     /// FTP server.
     ///
+    /// The append parameter controls whether the remote file is
+    /// appended to or overwritten if it already exists.
+    ///
     /// \param localFile  Path of the local file to upload
     /// \param remotePath The directory in which to put the file on the server
     /// \param mode       Transfer mode
+    /// \param append     Pass `true` to append to or `false` to overwrite the remote file if it already exists
     ///
     /// \return Server response to the request
     ///
-    /// \see download
+    /// \see `download`
     ///
     ////////////////////////////////////////////////////////////
-    Response upload(const std::string& localFile, const std::string& remotePath, TransferMode mode = Binary);
+    [[nodiscard]] Response upload(const std::filesystem::path& localFile,
+                                  const std::filesystem::path& remotePath,
+                                  TransferMode                 mode   = TransferMode::Binary,
+                                  bool                         append = false);
 
     ////////////////////////////////////////////////////////////
     /// \brief Send a command to the FTP server
     ///
     /// While the most often used commands are provided as member
-    /// functions in the sf::Ftp class, this method can be used
+    /// functions in the `sf::Ftp` class, this method can be used
     /// to send any FTP command to the server. If the command
     /// requires one or more parameters, they can be specified
-    /// in \a parameter. If the server returns information, you
-    /// can extract it from the response using Response::getMessage().
+    /// in `parameter`. If the server returns information, you
+    /// can extract it from the response using `Response::getMessage()`.
     ///
     /// \param command   Command to send
     /// \param parameter Command parameter
@@ -502,15 +523,14 @@ public:
     /// \return Server response to the request
     ///
     ////////////////////////////////////////////////////////////
-    Response sendCommand(const std::string& command, const std::string& parameter = "");
+    [[nodiscard]] Response sendCommand(const std::string& command, const std::string& parameter = "");
 
 private:
-
     ////////////////////////////////////////////////////////////
     /// \brief Receive a response from the server
     ///
     /// This function must be called after each call to
-    /// sendCommand that expects a response.
+    /// `sendCommand` that expects a response.
     ///
     /// \return Server response to the request
     ///
@@ -518,7 +538,7 @@ private:
     Response getResponse();
 
     ////////////////////////////////////////////////////////////
-    /// \brief Utility class for exchanging datas with the server
+    /// \brief Utility class for exchanging data with the server
     ///        on the data channel
     ///
     ////////////////////////////////////////////////////////////
@@ -529,21 +549,18 @@ private:
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    TcpSocket   m_commandSocket; ///< Socket holding the control connection with the server
-    std::string m_receiveBuffer; ///< Received command data that is yet to be processed
+    TcpSocket   m_commandSocket; //!< Socket holding the control connection with the server
+    std::string m_receiveBuffer; //!< Received command data that is yet to be processed
 };
 
 } // namespace sf
 
 
-#endif // SFML_FTP_HPP
-
-
 ////////////////////////////////////////////////////////////
 /// \class sf::Ftp
 /// \ingroup network
 ///
-/// sf::Ftp is a very simple FTP client that allows you
+/// `sf::Ftp` is a very simple FTP client that allows you
 /// to communicate with a FTP server. The FTP protocol allows
 /// you to manipulate a remote file system (list files,
 /// upload, download, create, remove, ...).
@@ -556,11 +573,11 @@ private:
 ///
 /// Every command returns a FTP response, which contains the
 /// status code as well as a message from the server. Some
-/// commands such as getWorkingDirectory() and getDirectoryListing()
+/// commands such as `getWorkingDirectory()` and `getDirectoryListing()`
 /// return additional data, and use a class derived from
-/// sf::Ftp::Response to provide this data. The most often used
+/// `sf::Ftp::Response` to provide this data. The most often used
 /// commands are directly provided as member functions, but it is
-/// also possible to use specific commands with the sendCommand() function.
+/// also possible to use specific commands with the `sendCommand()` function.
 ///
 /// Note that response statuses >= 1000 are not part of the FTP standard,
 /// they are generated by SFML when an internal error occurs.
@@ -596,7 +613,7 @@ private:
 ///     std::cout << "Created new directory" << std::endl;
 ///
 /// // Upload a file to this new directory
-/// response = ftp.upload("local-path/file.txt", "files", sf::Ftp::Ascii);
+/// response = ftp.upload("local-path/file.txt", "files", sf::Ftp::TransferMode::Ascii);
 /// if (response.isOk())
 ///     std::cout << "File uploaded" << std::endl;
 ///
